#[non_exhaustive]pub enum BacktestError {
InvalidSpec(String),
UnknownIndicator(String),
InvalidParams {
indicator: String,
reason: String,
},
UndeclaredRef(String),
InvalidData(String),
}Expand description
An error raised while parsing a strategy spec or running a backtest.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
InvalidSpec(String)
The strategy spec could not be parsed or was structurally invalid.
UnknownIndicator(String)
An indicator referenced in the spec is unknown to the registry.
InvalidParams
An indicator was constructed with the wrong number or value of parameters.
UndeclaredRef(String)
A rule referenced an indicator name that is not declared in indicators.
InvalidData(String)
The input data was empty or malformed.